KeyBytes

Struct KeyBytes 

#[repr(transparent)]
pub struct KeyBytes<const LEN: usize>(pub [u8; LEN]);
Generic wrapper for a fixed-length array of cryptographic key bytes, convertible to or from a base58-encoded string.

Tuple Fields

0: [u8; LEN]

Implementations

Source

impl<const LEN: usize> KeyBytes<LEN>

pub fn new(bytes: [u8; LEN]) -> KeyBytes<LEN>

Construct a new instance from the provided key bytes

pub fn into_bytes(self) -> [u8; LEN]

Return the public key bytes contained in this instance

pub fn try_from_ref<T>(key: T) -> Result<KeyBytes<LEN>, TryFromSliceError>
where T: AsRef<[u8]>,

Attempt to convert the provided byte slice to a new key byte array

Errors

This function returns an error if calling KeyBytes::try_from(slice) returns an error.

pub fn equals_ref<T>(&self, other: T) -> bool
where T: AsRef<[u8]>,

Compare the public key bytes contained in this array with the given byte slice