#[repr(transparent)]pub struct KeyBytes<const LEN: usize>(pub [u8; LEN]);Expand description
Generic wrapper for a fixed-length array of cryptographic key bytes, convertible to or from a base58-encoded string.
Tuple Fields
0: [u8; LEN]Implementations
Sourceimpl<const LEN: usize> KeyBytes<LEN>
impl<const LEN: usize> KeyBytes<LEN>
Sourcepub fn new(bytes: [u8; LEN]) -> KeyBytes<LEN>
pub fn new(bytes: [u8; LEN]) -> KeyBytes<LEN>
Construct a new instance from the provided key bytes
Sourcepub fn into_bytes(self) -> [u8; LEN]
pub fn into_bytes(self) -> [u8; LEN]
Return the public key bytes contained in this instance
Sourcepub fn try_from_ref<T>(key: T) -> Result<KeyBytes<LEN>, TryFromSliceError>
pub fn try_from_ref<T>(key: T) -> Result<KeyBytes<LEN>, TryFromSliceError>
Attempt to convert the provided byte slice to a new key byte array
Errors
This function returns an error if calling KeyBytes::try_from(slice)
returns an error.
Sourcepub fn equals_ref<T>(&self, other: T) -> bool
pub fn equals_ref<T>(&self, other: T) -> bool
Compare the public key bytes contained in this array with the given byte slice